@@ -99,26 +99,29 @@
 
 typedef struct
 {
-	const char *name;						// name of the device
-	const unsigned char *def;			// definition (initialization) (always 44 bytes long)
-	const unsigned char *defx;			// extended definition (initialization) (always 16 bytes long)
-	const unsigned short int cpbits;	// set of code protection bits in configuration word (0 = read protected)
-	const unsigned short int wdbit;	// watchdog enable bit in configuration word (1 = enabled)
-
-	// Additions below by Alexandre Nunes
-	// If set, these values override those guessed from the header.
-	const unsigned short int wordalign;	// Word alignment for writing to this device.
-	const unsigned int cfgmem;		// Configuration Memory Start addr
-	const unsigned int idaddr;		// Address of ID Locations area
-	const unsigned short int idsize;
-	const unsigned int eeaddr;		// Data EEPROM address
-	// Added by J. Post to handle factory set bits in config register (eg: band gap info)
-	const unsigned char fixedCfgBitsSize;		// number of words (1-8, 0 = no fixed bits)
-	const unsigned short int fixedCfgBits[8];	// up to 8 words of config bits
-	const unsigned short int pgm_support;	// bit map of supporting programmers
-	// More to come.
+	char						*name;		// name of the device
+	unsigned char			*def;			// definition (initialization) (always 44 bytes long)
+	unsigned char			*defx;		// extended definition (initialization) (always 16 bytes long)
+	unsigned short int	cpbits;		// set of code protection bits in configuration word (0 = read protected)
+	unsigned short int	wdbit;		// watchdog enable bit in configuration word (1 = enabled)
+	unsigned short int	wordalign;	// Word alignment for writing to this device.
+	unsigned int			cfgmem;		// Configuration Memory Start addr
+	unsigned int			idaddr;		// Address of ID Locations area
+	unsigned short int	idsize;
+	unsigned int			eeaddr;		// Data EEPROM address
+	unsigned char			fixedCfgBitsSize;	// number of words (1-8, 0 = no fixed bits)
+	unsigned short int	fixedCfgBits[8];	// up to 8 words of config bits
+	unsigned short int	pgm_support;	// bit map of supporting programmers
 } PIC_DEFINITION;
 
+// Linked list of PIC definitions
+
+typedef struct dev_list
+{
+	PIC_DEFINITION		picDef;	// the PIC device data
+	struct dev_list	*next;	// pointer to next device data
+} DEV_LIST;
+
 // return codes from blank check
 //
 #define BLANK_PGM		0x01		// 0 = program memory blank
@@ -126,6 +129,4 @@ typedef struct
 #define BLANK_ID		0x04		// 0 = ID locations blank
 #define BLANK_DATA	0x08		// 0 = EEPROM data blank
 
-extern const PIC_DEFINITION *deviceList[];
-
 #endif // defined __PICDEV_H_
