@@ -9,11 +9,18 @@
 //	Chicago, IL   60610
 //	http://www.cosmodog.com
 //
+// Maintained at
+// http://home.pacbell.net/theposts/picmicro
+//
 //-----------------------------------------------------------------------------
 
 #ifndef __SERIAL_H_
 #define __SERIAL_H_
 
+#ifdef WIN32
+#define	bool	int
+#endif
+
 bool	ByteWaiting(int theDevice, unsigned int timeOut);
 unsigned int	ReadBytes(int theDevice, unsigned char *theBytes, unsigned int maxBytes, unsigned int timeOut);
 void	WriteBytes(int theDevice, unsigned char *theBytes, unsigned int numBytes);
